@@ -161,26 +161,32 @@ void invoke(const gchar *cmd, const gchar *desktop, gboolean with_pkexec)
       return;
    }
 
-   // fake window to get the current server time *urgh*
-   if (!w) {
-      w = gtk_window_new(GTK_WINDOW_TOPLEVEL);
-      gtk_widget_realize (w);
-   }
-
    // normal launch
    context = gdk_display_get_app_launch_context (gdk_display_get_default ());
-   guint32 timestamp;
-#ifdef GDK_WINDOWING_X11
-   if (GDK_IS_X11_DISPLAY (gdk_display_get_default ()))
-      timestamp =  gdk_x11_get_server_time (gtk_widget_get_window (w));
-   else
-#endif
-   timestamp = (guint32) (g_get_monotonic_time () / 1000);
+   #ifdef GDK_WINDOWING_X11
+   if (GDK_IS_X11_DISPLAY (gdk_display_get_default ())) {
+      // fake window to get the current server time *urgh*
+      if (!w) {
+         w = gtk_window_new(GTK_WINDOW_TOPLEVEL);
+         gtk_widget_realize (w);
+      }
+
+      guint32 timestamp =  gdk_x11_get_server_time (gtk_widget_get_window (w));
+      gdk_app_launch_context_set_timestamp (context, timestamp);
+   } else {
+      guint32 timestamp =  (guint32) (g_get_monotonic_time () / 1000);
+      gdk_app_launch_context_set_timestamp (context, timestamp);
+   }
+   #else
+   {
+      guint32 timestamp =  (guint32) (g_get_monotonic_time () / 1000);
+      gdk_app_launch_context_set_timestamp (context, timestamp);
+   }
+   #endif
    appinfo = g_app_info_create_from_commandline(cmd, 
 						cmd, 
 						G_APP_INFO_CREATE_NONE,
 						&error);
-   gdk_app_launch_context_set_timestamp (context, timestamp);
    if (!g_app_info_launch (appinfo, NULL, (GAppLaunchContext*)context, &error))
       g_warning ("Launching failed: %s", error->message);
    g_object_unref (context);
